#!/usr/bin/ksh

#-----------------------------------------------------------------------------------------
#--
#-- Copyright (c) 2009-2012 ProactiveRA
#--
#-- This script is free software; you can redistribute it and/or modify it under
#-- the terms of the GNU Lesser General Public License as published by the Free
#-- Software Foundation; either version 3 of the License, or (at your option)
#-- any later version.
#--
#-- This script is distributed in the hope that it will be useful, but WITHOUT
#-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#-- FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
#-- details.
#--
#-- You should have received a copy of the GNU Lesser General Public License
#-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
#--
#-----------------------------------------------------------------------------------------

function init_global_variables {

  ###  Environment Variables  ###

  while read line ; do
        PASS_RA=$line;
  done < .PASS_RA

  while read line ; do
        PASS_BILLING=$line;
  done < .PASS_BILLING

  # Directories
  main_biv_dir=../../UnixStructure/BIV
  logfile_dir=../../UnixStructure/BIV/log
  extracted_biv_dir=${main_biv_dir}/extracted
  ready_biv_dir=${main_biv_dir}/ready
  resource_dir=${main_biv_dir}/bin/loading
  extract_query_dir=${main_biv_dir}/bin/extract

  my_extracted_files=list_extracted_files.dat

  source_name[0]="";
  main_directory[0]="";
  source_directory[0]="";
  remote_host[0]="";
  remote_user[0]="";
  remote_passwd[0]="";
  file_pattern[0]="";
  remote_directory[0]="";
  parsing_prg[0]="";
  oracle_table[0]="";
  rsh_allowed[0]="0";
  SQLS_UID[0]="";
  SQLS_PASS[0]="";
  SQLS_URL[0]="";

}

#-----------------------------------------------------------------------------------------

function start_and_prepare_logfile {

  if [[ $running_mode = "interactive" ]];then
     clear
  fi

  abort=0
  date=$(date +%Y%m%d_%H%M%S)
  logfile=${logfile_dir}/extracting_${main_directory[$1]}_${date}.log
  touch $logfile

}

#-----------------------------------------------------------------------------------------

function print_header {

  echo "##############################"
  echo "##############################"  >> $logfile
  echo "[$1] ${source_name[$1]} "
  echo "[$1] ${source_name[$1]} " >> $logfile
  echo "##############################"
  echo "##############################" >> $logfile

}

#-----------------------------------------------------------------------------------------

function validate_RA_DB_available {
 
  result=`sqlplus -s /NOLOG << ENDOFSQL
  connect ${UID_RA}/${PASS_RA}@${DB_RA}
 	set heading off feedback off verify off
  	select sysdate from dual;
	exit;
ENDOFSQL
`
  ora_error_found=`echo "$result" | grep 'ORA' | sed 's/.*ORA-/    => ORA-/' `
  if [ "$ora_error_found" ]
  then
 	# Error found... Log the Error and skip the rest of the processing (abort=1)
	echo "    => ERROR connecting to the database. Extract process aborted."
	echo "    => ERROR connecting to the database. Extract process aborted." >> $logfile 
	echo "$ora_error_found"
	echo "$ora_error_found" >> $logfile
	abort=1
  fi

  sp_error_found=`echo "$result" | grep 'SP' | sed 's/.*SP/    => SP/'`
  if [ "$sp_error_found" ]
  then
        # Error found... Log the Error and skip the rest of the processing (abort=1)
        if [ $abort = 0 ]; then
             echo "    => ERROR connecting to the ${DB_RA} database. Extract process aborted."
             echo "    => ERROR connecting to the ${DB_RA} database. Extract process aborted." >> $logfile
	fi
        echo "$sp_error_found"
        echo "$sp_error_found" >> $logfile
        abort=1
  fi
}

#-----------------------------------------------------------------------------------------

function get_last_extract_dt {

  echo "  Retrieving the last extract date..."
  echo "  Retrieving the last extract date..."  >> $logfile
  echo "  --------------------------------"
  echo "  --------------------------------" >> $logfile

  result=`sqlplus -s /NOLOG << ENDOFSQL
        connect ${UID_RA}/${PASS_RA}@${DB_RA}
        set heading off feedback off verify off
        SELECT '#1=', TO_CHAR(LAST_EXTRACT_DT, 'DD/MM/YYYY'), '#'
        FROM REF_BIV_SOURCES
        WHERE SOURCE_ID=$1;
        exit;
ENDOFSQL
`
  last_extract_dt=`echo "$result" | tr -d '[[\n],[:blank:]]' | sed 's/.*#1= *//' | sed 's/ *#.*//'`
  if [ "${last_extract_dt}" ]; then
           echo "    => Last Extract Date: [${last_extract_dt}]"
           echo "    => Last Extract Date: [${last_extract_dt}]" >> $logfile
           echo ""
           echo "" >> $logfile
	   echo "  Starting the extract..."
	   echo "  Starting the extract..." >> $logfile
  	   echo "  --------------------------------" 
  	   echo "  --------------------------------" >> $logfile
  else
           echo "    => ERROR Getting the last extract date. Extract process aborted."
           echo "    => ERROR Getting the last extract date. Extract process aborted." >> $logfile
           abort=1
  fi

}

#-----------------------------------------------------------------------------------------

function update_last_extract_dt {

  echo "  Updating Last Extract Date..."
  echo "  Updating Last Extract Date..." >> $logfile

  result=`sqlplus -s /NOLOG << ENDOFSQL
         connect ${UID_RA}/${PASS_RA}@${DB_RA}
         UPDATE REF_BIV_SOURCES
         SET LAST_EXTRACT_DT=TRUNC(SYSDATE, 'DD')
         WHERE SOURCE_ID=$1;
         COMMIT;
         exit;
ENDOFSQL
`
}

#-----------------------------------------------------------------------------------------

function finish_log_and_end {

  echo "  --------------------------------"
  echo "  --------------------------------" >> $logfile
  echo "  Done."
  echo "  Done." >> $logfile

  echo ""
  echo "" >> $logfile

  if [[ $running_mode = "interactive" ]];then
     echo "Press Enter to return to the main menu"
     read unused
  fi

}

#-----------------------------------------------------------------------------------------
