#!/usr/bin/ksh

#-----------------------------------------------------------------------------------------
#--
#-- Copyright (c) 2009-2012 ProactiveRA
#--
#-- This script is free software; you can redistribute it and/or modify it under
#-- the terms of the GNU Lesser General Public License as published by the Free
#-- Software Foundation; either version 3 of the License, or (at your option)
#-- any later version.
#--
#-- This script is distributed in the hope that it will be useful, but WITHOUT
#-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#-- FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
#-- details.
#--
#-- You should have received a copy of the GNU Lesser General Public License
#-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
#--
#-----------------------------------------------------------------------------------------

. ../Common/lib.ksh

MODULE="SDR"

#identify if we need to run in batch mode or interactive mode
if [[ $# = 0 ]];then
  running_mode=interactive
else
  running_mode=batch
fi

init_global_variables
abort=0


#############################

function purge_option {
 
  # Prepare name of the log file
  date=$(date +%Y%m%d_%H%M%S)
  logfile=${logfile_dir}/purge_db_SDR_${date}.log
  touch $logfile

  if [[ $running_mode = "interactive" ]];then
	clear
  fi

  echo "##############################"  
  echo "##############################"  >> $logfile
  echo "Database Purge"
  echo "Database Purge" >> $logfile
  echo "##############################" 
  echo "##############################" >> $logfile
  echo "  Starting the Purge..." 
  echo "  Starting the Purge..." >> $logfile
  echo "  ---------------------" 
  echo "  ---------------------" >> $logfile

  # Step 1 - Verify availability of database before attempting loading anything
  validate_RA_DB_available

  if [ $abort = 0 ]; then
  	# No Error - Continue

 	# Step 2: Execute the SQL-Procedures to purge all
	# Execute the post-processing
	echo "  Executing P_SDR_PURGE_ALL"
	echo "  Executing P_SDR_PURGE_ALL" >> $logfile
	result=`sqlplus -s /NOLOG << ENDOFSQL
	connect ${UID_RA}/${PASS_RA}@${DB_RA}
	execute P_SDR_PURGE_ALL;
	exit;
ENDOFSQL
`
	#look for Oracle error codes 
	search_and_log_ORACLE_error ${DB_RA}

	if [ $abort = 0 ]; then
	  	# No Error
		echo "    => Success"
		echo "    => Success" >> $logfile
		echo ""
		echo "" >> $logfile
	fi 
	
  fi

  echo ""
  echo "" >> $logfile
  if [[ $running_mode = "interactive" ]];then
     echo "Press Enter to return to the main menu"
     read unused
  fi
}

#############################

choice=-1

if [[ $running_mode = "batch" ]];then
   purge_option $1
else

   while [ $choice -ne 0 ]
   do

	clear

	echo ""; echo ""; echo ""
	echo "    ###############################################"
	echo "    #                                             #"
	echo "    #            - REVENUE ASSURANCE -            #"
	echo "    #            Subscriber Integrity             #"
	echo "    #                                             #"
	echo "    #             Purge Dabatabase                #"
	echo "    #                                             #"
	echo "    ###############################################"
	echo ""
	echo ""
	echo "Confirmation :"
	echo "-------------"
	echo "This will erase data in the database permanently"
	echo "Only the configured nbr of loads for each platform will be kept."
	echo ""
	echo "  1) Confirm"
	echo "  0) Cancel"
	echo ""
	echo "Select your option: "
	read choice

	case "$choice" in
	 1 ) purge_option 1 ; choice=0;;
	 0 ) clear; exit 1 ;;
	 *)  clear; echo "Wrong option entered"; echo "Press Enter"; read unused; choice=-1;;
	esac

   done

fi
